@@ -808,10 +808,23 @@ summary.spendfn <- function(object, ...) {
     if (!is.null(object$param$parname)) {
       s <- paste(s, " with", paste(object$param$parname, collapse = " "), "=", paste(object$param$param, collapse = " "))
     }
-  } else {
+  }
+  else if (object$name == "Lan-DeMets O'Brien-Fleming approximation") {
+    if (object$parname == "none") {
+      s <- "Lan-DeMets O'Brien-Fleming approximation spending function (no parameters)"
+    }
+    else {
+      s <- paste(s, "with", paste(object$parname, collapse = " "), "=", paste(object$param, collapse = " "))
+    }
+  }
+  else {
     s <- paste(object$name, "spending function")
     if (!is.null(object$parname) && !is.null(object$param)) {
-      s <- paste(s, "with", paste(object$parname, collapse = " "), "=", paste(object$param, collapse = " "))
+      # Use %s for the numeric object$param in order to preserve the decimal
+      # places entered by the user
+      params <- sprintf("%s = %s", object$parname, round(object$param, digits = 5))
+      params <- paste(params, collapse = ", ")
+      s <- paste(s, "with", params)
     }
   }
   return(s)
